@PROCESS VECTOR DIR('@DIR')
      SUBROUTINE QGET (HOST, AP, N, TYPE)
C-----------------------------------------------------------------------
C! Pseudo AP routine: Move data from pseudo-AP memory to "host".
C# AP-appl
C-----------------------------------------------------------------------
C;  Copyright (C) 1995
C;  Associated Universities, Inc. Washington DC, USA.
C;
C;  This program is free software; you can redistribute it and/or
C;  modify it under the terms of the GNU General Public License as
C;  published by the Free Software Foundation; either version 2 of
C;  the License, or (at your option) any later version.
C;
C;  This program is distributed in the hope that it will be useful,
C;  but WITHOUT ANY WARRANTY; without even the implied warranty of
C;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C;  GNU General Public License for more details.
C;
C;  You should have received a copy of the GNU General Public
C;  License along with this program; if not, write to the Free
C;  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
C;  MA 02139, USA.
C;
C;  Correspondence concerning AIPS should be addressed as follows:
C;         Internet email: aipsmail@nrao.edu.
C;         Postal address: AIPS Project Office
C;                         National Radio Astronomy Observatory
C;                         520 Edgemont Road
C;                         Charlottesville, VA 22903-2475 USA
C-----------------------------------------------------------------------
C-----------------------------------------------------------------------
C   Transfer data from pseudo-AP core to normal core
C   Inputs:
C      AP     I  Target area in AP; 0-relative
C      N      I  Number of elements
C      TYPE   I  Data type:
C                 0   data is I   in host
C                 1   data is I   in host
C                 2   data is R   in host
C   Output:
C      HOST   R/I(*)  Data array in "host"
C-----------------------------------------------------------------------
      INTEGER   AP, I, N, TYPE
      REAL      HOST(*)
      INCLUDE 'INCS:DAPC.INC'
C-----------------------------------------------------------------------
      IF (TYPE.GT.2) GO TO 999
      IF (N.LE.0) GO TO 999
C                                       Real data
      IF (TYPE .EQ. 1) THEN
         CALL QGET2 (HOST, AP, N)
      ELSE
C        DO 50 I = 1, N
C           HOST(I) = APCORE(AP+I)
C50         CONTINUE
         CALL SCOPY(N,APCORE(AP+1),1,HOST,1)
       ENDIF
C
 999  RETURN
      END
